require "faraday"
require "JSON"
require "mimemagic"

require "app"
require "api_url"

module Flubber
  class AwsFileUpload
    def self.upload(file_path:, aws_destination:)
      new(file_path, aws_destination).upload
    end

    def initialize(file_path, aws_destination)
      @file_path = file_path
      @aws_destination = aws_destination
    end

    def upload
      connection.post("/", payload)
    end

    private

    attr_reader :file_path, :aws_destination

    def connection
      @connection ||= Faraday.new(presigned_post["url"]) do |f|
        f.request :multipart
        f.request :url_encoded
        f.adapter :net_http
      end
    end

    def payload
      @payload ||= presigned_post["fields"].merge(
        :file => Faraday::UploadIO.new(file_path, content_type),
      )
    end

    def presigned_post
      @presigned_post ||= JSON.parse(Faraday.post(
        "#{API_URL}/presigned_posts",
        {
          "app_uuid": app_uuid,
          "aws_directory": aws_destination,
          "content_type": content_type,
        },
        {
          "Authorization" => "Bearer #{api_token}"
        }
      ).body)
    end

    def api_token
      @api_token ||= ApiToken.get
    end

    def app_uuid
      @app_uuid ||= App.uuid
    end

    def content_type
      @content_type ||= begin
        MimeMagic.by_path(file_path).type
      rescue
        "binary/octet-stream"
      end
    end
  end
end
