require "aws_file_upload"

module Flubber
  class AwsFolderUpload
    IGNORED_FILES = [".DS_Store"]

    def self.upload(folder_name:, aws_destination:)
      new(folder_name, aws_destination).upload
    end

    def initialize(folder_name, aws_destination)
      @folder_name = folder_name
      @aws_destination = aws_destination
    end

    def upload
      file_paths.each do |file_path|
        AwsFileUpload.upload(
          file_path: file_path,
          aws_destination: aws_destination,
        )
      end
    end

    private

    attr_reader :folder_name, :aws_destination

    def file_paths
      @file_paths ||= Dir
        .children("./#{folder_name}")
        .filter { |file| !IGNORED_FILES.include?(file) }
        .map { |file| File.expand_path("#{folder_name}/#{file}") }
        .filter { |file| !File.directory?(file) }
    end
  end
end
