require "io/console"
require "faraday"
require "JSON"
require "active_support"
require "active_support/core_ext"

require "api_url"
require "api_token"

module Flubber
  class Login
    def self.login
      new.login
    end

    def login
      if logged_in?
        puts "Already logged in."
      else
        get_credentials
        get_api_token
        save_api_token
      end
    end

    private

    attr_reader :phone_number, :password, :api_token

    def get_credentials
      print "Phone Number: "
      @phone_number = STDIN.gets.chomp
      print "Password: "
      @password = IO::console.getpass
    end

    def get_api_token
      if api_token_response.status == 201
        @api_token = JSON.parse(api_token_response.body)["api_token"]
      end
    end

    def save_api_token
      if api_token.present?
        ApiToken.set(api_token)
        puts "Success"
      else
        puts "Incorrect credentials"
      end
    end

    def api_token_response
      @api_token_response ||= Faraday.post(
        "#{API_URL}/user_token",
        {
          "phone_number": phone_number,
          "password": password,
        },
      )
    end

    def logged_in?
      @logged_in ||= ApiToken.get.present?
    end
  end
end
